Default token counter using a bytes / 4 heuristic.
This approximation is commonly used as a rough estimate for English text across most LLM tokenizers.
Default token counter using a bytes / 4 heuristic.
This approximation is commonly used as a rough estimate for English text across most LLM tokenizers.